pub enum FramingError {
InvalidHeader,
InvalidHeaderUtf8,
MissingContentLength,
InvalidContentLength,
FrameTooLarge {
len: usize,
},
}Expand description
Framing errors for Content-Length transport parsing.
Variants
InvalidHeader
Header bytes could not be interpreted as a valid frame header.
InvalidHeaderUtf8
Header bytes were not valid UTF-8.
MissingContentLength
Content-Length header was missing from a complete header block.
InvalidContentLength
Content-Length value was not a valid non-negative integer.
FrameTooLarge
Content-Length exceeded MAX_FRAME_SIZE.